@@ -980,17 +980,8 @@ bool synthv1_jack_application::setup (void)
 
 	m_pSynth = new synthv1_jack(client_name);
 
-	if (m_bGui) {
+	if (m_bGui)
 		m_pWidget = new synthv1widget_jack(m_pSynth);
-	//	m_pWidget->show();
-		if (m_presets.isEmpty())
-			m_pWidget->initPreset();
-		else
-			m_pWidget->loadPreset(m_presets.first());
-	}
-	else
-	if (!m_presets.isEmpty())
-		synthv1_param::loadPreset(m_pSynth, m_presets.first());
 
 #ifdef CONFIG_NSM
 	// Check whether to participate into a NSM session...
@@ -1019,8 +1010,16 @@ bool synthv1_jack_application::setup (void)
 	}
 	else
 #endif	// CONFIG_NSM
-	if (m_pWidget)
+	if (m_pWidget) {
 		m_pWidget->show();
+		if (m_presets.isEmpty())
+			m_pWidget->initPreset();
+		else
+			m_pWidget->loadPreset(m_presets.first());
+	}
+	else
+	if (!m_presets.isEmpty())
+		synthv1_param::loadPreset(m_pSynth, m_presets.first());
 
 	// Start watchdog timer...
 	watchdog_start();
@@ -1069,9 +1068,9 @@ void synthv1_jack_application::openSession (void)
 
 	bool bOpen = false;
 
-	QFileInfo fi(path_name, "session." PROJECT_NAME);
+	QFileInfo fi(path_name, display_name + '.' + PROJECT_NAME);
 	if (!fi.exists())
-		fi.setFile(path_name, display_name + '.' + PROJECT_NAME);
+		fi.setFile(path_name, "session." PROJECT_NAME);
 	if (fi.exists()) {
 		const QString& sFilename = fi.absoluteFilePath();
 		if (m_pWidget) {
@@ -1107,9 +1106,8 @@ void synthv1_jack_application::saveSession (void)
 
 //	const QString& client_name = m_pNsmClient->client_name();
 	const QString& path_name = m_pNsmClient->path_name();
-//	const QString& display_name = m_pNsmClient->display_name();
-//	const QFileInfo fi(path_name, display_name + '.' + PROJECT_NAME);
-	const QFileInfo fi(path_name, "session." PROJECT_NAME);
+	const QString& display_name = m_pNsmClient->display_name();
+	QFileInfo fi(path_name, display_name + '.' + PROJECT_NAME);
 
 	const bool bSave
 		= synthv1_param::savePreset(m_pSynth, fi.absoluteFilePath(), true);
@@ -1118,6 +1116,11 @@ void synthv1_jack_application::saveSession (void)
 		? synthv1_nsm::ERR_OK
 		: synthv1_nsm::ERR_GENERAL);
 	m_pNsmClient->dirty(false);
+
+	fi.setFile(path_name, "session." PROJECT_NAME);
+	if (fi.exists())
+		QFile::remove(fi.absoluteFilePath());
+
 }
 
 
