@@ -834,13 +834,7 @@ synthv1widget::synthv1widget ( QWidget *pParent )
 		SLOT(helpAboutQt()));
 
 	// General knob/dial  behavior init...
-	synthv1_config *pConfig = synthv1_config::getInstance();
-	if (pConfig) {
-		synthv1widget_dial::setDialMode(
-			synthv1widget_dial::DialMode(pConfig->iKnobDialMode));
-		synthv1widget_edit::setEditMode(
-			synthv1widget_edit::EditMode(pConfig->iKnobEditMode));
-	}
+	updateConfig();
 
 	// Epilog.
 	// QWidget::adjustSize();
@@ -1391,6 +1385,19 @@ bool synthv1widget::queryClose (void)
 }
 
 
+// Update visual configuration.
+void synthv1widget::updateConfig (void)
+{
+	synthv1_config *pConfig = synthv1_config::getInstance();
+	if (pConfig) {
+		synthv1widget_dial::setDialMode(
+			synthv1widget_dial::DialMode(pConfig->iKnobDialMode));
+		synthv1widget_edit::setEditMode(
+			synthv1widget_edit::EditMode(pConfig->iKnobEditMode));
+	}
+}
+
+
 // Preset status updater.
 void synthv1widget::updateLoadPreset ( const QString& sPreset )
 {
