@@ -102,10 +102,12 @@ synthv1widget_lv2::synthv1widget_lv2 ( synthv1_lv2 *pSynth,
 					pConfig, pConfig->sCustomColorTheme, pal))
 				synthv1widget::setPalette(pal);
 		}
+	#if 0//--Not applicable to plugin forms...
 		if (!pConfig->sCustomStyleTheme.isEmpty()) {
-			synthv1widget::setStyle(
+			QApplication::setStyle(
 				QStyleFactory::create(pConfig->sCustomStyleTheme));
 		}
+	#endif
 	}
 
 	// Initialize (user) interface stuff...
